summaryrefslogtreecommitdiff
path: root/Makefile.SH
diff options
context:
space:
mode:
authorGraham Barr <gbarr@pobox.com>1998-06-19 06:31:04 -0500
committerGurusamy Sarathy <gsar@cpan.org>1998-06-21 06:51:38 +0000
commit4318d5a0158916acc059aa8e6af84037cb7296b9 (patch)
treeeed01f63911055a71417415226fec5ef7fb4d955 /Makefile.SH
parent0f4eea8fa1779e08575278392ed398ffeda6dcd2 (diff)
downloadperl-4318d5a0158916acc059aa8e6af84037cb7296b9.tar.gz
applied patch, modified logic to avoid reentering lexer at compile-time
Message-ID: <19980619113104.S9711@asic.sc.ti.com> Subject: Re: [PATCH perl5.004_67] Add Errno in ext/ p4raw-id: //depot/perl@1173
Diffstat (limited to 'Makefile.SH')
-rw-r--r--Makefile.SH26
1 files changed, 18 insertions, 8 deletions
diff --git a/Makefile.SH b/Makefile.SH
index 4f78f57d74..5150a22f1a 100644
--- a/Makefile.SH
+++ b/Makefile.SH
@@ -85,6 +85,12 @@ for f in $static_ext; do
static_list="$static_list lib/auto/$f/$base\$(LIB_EXT)"
done
+nonxs_list=' '
+for f in $nonxs_ext; do
+ base=`echo "$f" | sed 's/.*\///'`
+ nonxs_list="$nonxs_list ext/$f/pm_to_blib"
+done
+
echo "Extracting Makefile (with variable substitutions)"
$spitshell >Makefile <<!GROK!THIS!
# Makefile.SH
@@ -140,7 +146,8 @@ LDLIBPTH = $ldlibpth
dynamic_ext = $dynamic_list
static_ext = $static_list
-ext = \$(dynamic_ext) \$(static_ext)
+nonxs_ext = $nonxs_list
+ext = \$(dynamic_ext) \$(static_ext) \$(nonxs_ext)
DYNALOADER = lib/auto/DynaLoader/DynaLoader\$(LIB_EXT)
libs = $libs $cryptlib
@@ -230,7 +237,7 @@ lintflags = -hbvxac
.c$(OBJ_EXT):
$(CCCMD) $(PLDLFLAGS) $*.c
-all: $(FIRSTMAKEFILE) miniperl $(private) $(plextract) $(public) $(dynamic_ext)
+all: $(FIRSTMAKEFILE) miniperl $(private) $(plextract) $(public) $(dynamic_ext) $(nonxs_ext)
@echo " "; echo " Everything is up to date."
compile: all
@@ -454,9 +461,9 @@ regen_headers: FORCE
perl bytecode.pl
# Extensions:
# Names added to $(dynamic_ext) or $(static_ext) will automatically
# get built. There should ordinarily be no need to change any of
# this part of makefile.
#
# The dummy dependency is a place holder in case $(dynamic_ext) or
# $(static_ext) is empty.
@@ -472,6 +479,9 @@ d_dummy $(dynamic_ext): miniperl preplibrary $(DYNALOADER) FORCE
s_dummy $(static_ext): miniperl preplibrary $(DYNALOADER) FORCE
@$(LDLIBPTH) sh ext/util/make_ext static $@ MAKE=$(MAKE) LIBPERL_A=$(LIBPERL)
+n_dummy $(nonxs_ext): miniperl preplibrary $(DYNALOADER) FORCE
+ @$(LDLIBPTH) sh ext/util/make_ext nonxs $@ MAKE=$(MAKE) LIBPERL_A=$(LIBPERL)
+
clean: _tidy _mopup
realclean: _cleaner _mopup
@@ -494,7 +504,7 @@ _tidy:
-cd pod; $(MAKE) clean
-cd utils; $(MAKE) clean
-cd x2p; $(MAKE) clean
- -@for x in $(DYNALOADER) $(dynamic_ext) $(static_ext) ; do \
+ -@for x in $(DYNALOADER) $(dynamic_ext) $(static_ext) $(nonxs_ext) ; do \
sh ext/util/make_ext clean $$x MAKE=$(MAKE) ; \
done
rm -f testcompile compilelog
@@ -505,7 +515,7 @@ _cleaner:
-cd pod; $(MAKE) realclean
-cd utils; $(MAKE) realclean
-cd x2p; $(MAKE) realclean
- -@for x in $(DYNALOADER) $(dynamic_ext) $(static_ext) ; do \
+ -@for x in $(DYNALOADER) $(dynamic_ext) $(static_ext) $(nonxs_ext) ; do \
sh ext/util/make_ext realclean $$x MAKE=$(MAKE) ; \
done
rm -f *.orig */*.orig *~ */*~ core t/core t/c t/perl
@@ -552,7 +562,7 @@ depend: makedepend
makedepend: makedepend.SH config.sh
sh ./makedepend.SH
-test-prep: miniperl perl preplibrary utilities $(dynamic_ext)
+test-prep: miniperl perl preplibrary utilities $(dynamic_ext) $(nonxs_ext)
cd t && (rm -f perl$(EXE_EXT); $(LNS) ../perl$(EXE_EXT) perl$(EXE_EXT))
test check: test-prep
@@ -454,9 +461,9 @@ regen_headers: FORCE
perl bytecode.pl
# Extensions:
-# Names added to $(dynamic_ext) or $(static_ext) will automatically
-# get built. There should ordinarily be no need to change any of
-# this part of makefile.
+# Names added to $(dynamic_ext) or $(static_ext) or $(nonxs_ext) will
+# automatically get built. There should ordinarily be no need to change
+# any of this part of makefile.
#
# The dummy dependency is a place holder in case $(dynamic_ext) or